@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: (GPL-2.0-or-later OR BSD-2-Clause)
 /*
  * Traceshark - a visualizer for visualizing ftrace and perf traces
- * Copyright (C) 2014, 2015, 2016, 2018, 2020
+ * Copyright (C) 2014-2016, 2018, 2020-2021
  * Viktor Rosendahl <viktor.rosendahl@gmail.com>
  *
  * This file is dual licensed: you can use it either under the terms of
@@ -109,8 +109,6 @@ int main(int argc, char* argv[])
 	QPixmap pm(QLatin1String(RESSRC_GPH_SHARK));
 	QIcon icon;
 	QString appname = QLatin1String("Traceshark");
-	QRect geometry;
-	int width, height;
 	QString fileName;
 
 	vtl::set_strerror(ts_strerror);
@@ -134,13 +132,6 @@ int main(int argc, char* argv[])
 
 	mainWindow.show();
 
-	geometry = QApplication::desktop()->availableGeometry();
-
-
-	width = geometry.width() - geometry.width() / 32;
-	height = geometry.height() - geometry.height() / 16;
-
-	mainWindow.resize(width, height);
 	if (!fileName.isEmpty())
 		mainWindow.openFile(fileName);
 
