@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: (GPL-2.0-or-later OR BSD-2-Clause)
 /*
  * Traceshark - a visualizer for visualizing ftrace and perf traces
- * Copyright (C) 2015, 2016, 2017, 2019, 2020
+ * Copyright (C) 2015, 2016, 2017, 2019-2021
  * Viktor Rosendahl <viktor.rosendahl@gmail.com>
  *
  * This file is dual licensed: you can use it either under the terms of
@@ -52,36 +52,20 @@
  */
 
 #include "parser/traceevent.h"
+#include "misc/types.h"
 #include "mm/stringtree.h"
 
-/* Do not change the order of these without updating the enum in
- * traceevent.h */
-
-static char cpufreqstr[] = "cpu_frequency";
-static char cpuidlestr[] = "cpu_idle";
-static char migratestr[] = "sched_migrate_task";
-static char sswitchstr[] = "sched_switch";
-static char swakeupstr[] = "sched_wakeup";
-static char swaknewstr[] = "sched_wakeup_new";
-static char swakingstr[] = "sched_waking";
-static char sprforkstr[] = "sched_process_fork";
-static char sprexitstr[] = "sched_process_exit";
-static char irqhdlrent[] = "irq_handler_entry";
-static char irqhdlrext[] = "irq_handler_exit";
-
-char *eventstrings[NR_EVENTS] = {
-	cpufreqstr,
-	cpuidlestr,
-	migratestr,
-	sswitchstr,
-	swakeupstr,
-	swaknewstr,
-	swakingstr,
-	sprforkstr,
-	sprexitstr,
-	irqhdlrent,
-	irqhdlrext
+/* TSHARK_ITEM_ is used by the TRACEEVENT_DEFS_ macro */
+#undef TSHARK_ITEM_
+#define TSHARK_ITEM_(A, B) B
+/*
+ * The maximum length of these strings should be in the macro
+ * EVENTSTRINGS_MAXLEN, which is defined misc/types.h
+ */
+const char * const eventstrings[] = {
+	TRACEEVENTS_DEFS_
 };
+#undef TSHARK_ITEM_
 
 StringTree<> *TraceEvent::stringTree = nullptr;
 
