@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: (GPL-2.0-or-later OR BSD-2-Clause)
 /*
  * Traceshark - a visualizer for visualizing ftrace and perf traces
- * Copyright (C) 2014-2020  Viktor Rosendahl <viktor.rosendahl@gmail.com>
+ * Copyright (C) 2014-2021  Viktor Rosendahl <viktor.rosendahl@gmail.com>
  *
  * This file is dual licensed: you can use it either under the terms of
  * the GPL, or the BSD license, at your option.
@@ -169,6 +169,6 @@ private:
 	static StringTree<> *stringTree;
 };
 
-extern char *eventstrings[];
+extern const char * const eventstrings[];
 
-#endif
+#endif /* TRACEEVENT_H */
